@@ -1,5 +1,13 @@
+# Copyright (c) 2010-18, Enthought, Inc.
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in enthought/LICENSE.txt and may be redistributed only
+# under the conditions described in the aforementioned license.  The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+# Thanks for using Enthought open source!
 
-
+from __future__ import absolute_import
 
 # Local imports.
 from .advanced_editor_area_pane import AdvancedEditorAreaPane
@@ -15,6 +23,7 @@ from .i_editor import IEditor
 from .i_editor_area_pane import IEditorAreaPane
 from .i_task_pane import ITaskPane
 from .task import Task
+from .tasks_application import TasksApplication, TaskFactory
 from .task_layout import TaskLayout, PaneItem, Tabbed, Splitter, HSplitter, \
     VSplitter
 from .task_pane import TaskPane
