@@ -21,6 +21,7 @@ from .find_widget import FindWidget
 from .gutters import LineNumberWidget, StatusGutterWidget
 from .replace_widget import ReplaceWidget
 from .pygments_highlighter import PygmentsHighlighter
+import six
 
 
 class CodeWidget(QtGui.QPlainTextEdit):
@@ -129,7 +130,7 @@ class CodeWidget(QtGui.QPlainTextEdit):
     def get_selected_text(self):
         """ Return the currently selected text.
         """
-        return str(self.textCursor().selectedText())
+        return six.text_type(self.textCursor().selectedText())
 
     def set_font(self, font):
         """ Set the new QFont.
@@ -358,7 +359,7 @@ class CodeWidget(QtGui.QPlainTextEdit):
         """
         cursor = self.textCursor()
         cursor.select(QtGui.QTextCursor.WordUnderCursor)
-        return str(cursor.selectedText())
+        return six.text_type(cursor.selectedText())
 
     ###########################################################################
     # QWidget interface
@@ -658,7 +659,7 @@ class AdvancedCodeWidget(QtGui.QWidget):
     def find_next(self):
         if not self.active_find_widget:
             self.enable_find()
-        search_text = str(self.active_find_widget.line_edit.text())
+        search_text = six.text_type(self.active_find_widget.line_edit.text())
         cursor = self.find_in_document(search_text=search_text)
 
         if cursor:
@@ -668,7 +669,7 @@ class AdvancedCodeWidget(QtGui.QWidget):
     def find_prev(self):
         if not self.active_find_widget:
             self.enable_find()
-        search_text = str(self.active_find_widget.line_edit.text())
+        search_text = six.text_type(self.active_find_widget.line_edit.text())
         cursor = self.find_in_document(search_text=search_text,
                                        direction='backward')
         if cursor:
@@ -689,8 +690,8 @@ class AdvancedCodeWidget(QtGui.QWidget):
         return 0
 
     def replace_all(self):
-        search_text = str(self.replace.line_edit.text())
-        replace_text = str(self.replace.replace_edit.text())
+        search_text = six.text_type(self.replace.line_edit.text())
+        replace_text = six.text_type(self.replace.replace_edit.text())
 
         count = 0
         cursor = self.code.textCursor()
