@@ -18,7 +18,8 @@
 """
 
 # Standard library imports.
-import builtins
+from __future__ import print_function
+import six.moves.builtins
 import codeop
 import re
 import sys
@@ -39,6 +40,7 @@ from pyface.wx.drag_and_drop import PythonDropTarget
 
 # Local imports.
 from .widget import Widget
+import six
 
 # Constants.
 IPYTHON_VERSION = tuple(map(int, IPython.Release.version_base.split('.')))
@@ -115,10 +117,10 @@ class IPython09Controller(IPythonController):
         # Suppress all key input, to avoid waiting
         def my_rawinput(x=None):
             return '\n'
-        old_rawinput = builtins.raw_input
-        builtins.raw_input = my_rawinput
+        old_rawinput = six.moves.builtins.raw_input
+        six.moves.builtins.raw_input = my_rawinput
         IPythonController.__init__(self, *args, **kwargs)
-        builtins.raw_input = old_rawinput
+        six.moves.builtins.raw_input = old_rawinput
 
         # XXX: This is bugware for IPython bug:
         # https://bugs.launchpad.net/ipython/+bug/270998
@@ -403,7 +405,7 @@ class IPythonWidget(Widget):
             name = 'dragged'
 
             if hasattr(obj, 'name') \
-                    and isinstance(obj.name, str) and len(obj.name) > 0:
+                    and isinstance(obj.name, six.string_types) and len(obj.name) > 0:
                 py_name = python_name(obj.name)
 
                 # Make sure that the name is actually a valid Python identifier.
